@@ -5,6 +5,7 @@ pub mod keyboard;
 pub mod navigation;
 pub mod renderer;
 pub mod theme;
+pub mod title;
 pub mod window;
 
 use crate::ansi::CursorShape;
@@ -13,6 +14,7 @@ use crate::config::defaults::*;
 use crate::config::keyboard::Keyboard;
 use crate::config::navigation::Navigation;
 use crate::config::renderer::Renderer;
+use crate::config::title::Title;
 use crate::config::window::Window;
 use colors::Colors;
 use serde::{Deserialize, Serialize};
@@ -33,9 +35,26 @@ pub enum ConfigError {
 #[derive(Default, Debug, Serialize, Deserialize, PartialEq, Clone)]
 pub struct Shell {
     pub program: String,
+    #[serde(default)]
     pub args: Vec<String>,
 }
 
+#[derive(Default, Debug, Serialize, Deserialize, PartialEq, Clone)]
+pub struct Platform {
+    pub linux: Option<PlatformConfig>,
+    pub windows: Option<PlatformConfig>,
+    pub macos: Option<PlatformConfig>,
+}
+
+/// Other platform specific configuration options can be added here.
+#[derive(Default, Debug, Serialize, Deserialize, PartialEq, Clone)]
+pub struct PlatformConfig {
+    shell: Option<Shell>,
+    navigation: Option<Navigation>,
+    window: Option<Window>,
+    renderer: Option<Renderer>,
+}
+
 #[derive(Debug, Serialize, Deserialize, PartialEq, Clone)]
 pub struct Scroll {
     pub multiplier: f64,
@@ -81,10 +100,14 @@ pub struct Config {
     pub window: Window,
     #[serde(default = "default_shell")]
     pub shell: Shell,
+    #[serde(default = "Platform::default")]
+    pub platform: Platform,
     #[serde(default = "default_use_fork", rename = "use-fork")]
     pub use_fork: bool,
     #[serde(default = "Keyboard::default")]
     pub keyboard: Keyboard,
+    #[serde(default = "Title::default")]
+    pub title: Title,
     #[serde(default = "default_working_dir", rename = "working-dir")]
     pub working_dir: Option<String>,
     #[serde(rename = "line-height", default = "default_line_height")]
@@ -134,6 +157,8 @@ pub struct Config {
     pub hide_cursor_when_typing: bool,
     #[serde(default = "Renderer::default")]
     pub renderer: Renderer,
+    #[serde(default = "bool::default", rename = "draw-bold-text-with-light-colors")]
+    pub draw_bold_text_with_light_colors: bool,
 }
 
 #[derive(Debug, Clone, Serialize, Deserialize, PartialEq)]
@@ -414,6 +439,41 @@ impl Config {
             Err(ConfigError::PathNotFound)
         }
     }
+
+    pub fn overwrite_based_on_platform(&mut self) {
+        #[cfg(windows)]
+        if let Some(windows) = &self.platform.windows {
+            self.overwrite_with_platform_config(windows.clone());
+        }
+
+        #[cfg(target_os = "linux")]
+        if let Some(linux) = &self.platform.linux {
+            self.overwrite_with_platform_config(linux.clone());
+        }
+
+        #[cfg(target_os = "macos")]
+        if let Some(macos) = &self.platform.macos {
+            self.overwrite_with_platform_config(macos.clone());
+        }
+    }
+
+    fn overwrite_with_platform_config(&mut self, platform_config: PlatformConfig) {
+        if let Some(shell_overwrite) = &platform_config.shell {
+            self.shell = shell_overwrite.clone();
+        }
+
+        if let Some(window_overwrite) = &platform_config.window {
+            self.window = window_overwrite.clone();
+        }
+
+        if let Some(navigation_overwrite) = &platform_config.navigation {
+            self.navigation = navigation_overwrite.clone();
+        }
+
+        if let Some(renderer_overwrite) = &platform_config.renderer {
+            self.renderer = renderer_overwrite.clone();
+        }
+    }
 }
 
 impl Default for Config {
@@ -427,6 +487,7 @@ impl Default for Config {
             colors: Colors::default(),
             scroll: Scroll::default(),
             keyboard: Keyboard::default(),
+            title: Title::default(),
             developer: Developer::default(),
             env_vars: vec![],
             fonts: SugarloafFonts::default(),
@@ -437,6 +498,7 @@ impl Default for Config {
             padding_y: default_padding_y(),
             renderer: Renderer::default(),
             shell: default_shell(),
+            platform: Platform::default(),
             theme: String::default(),
             use_fork: default_use_fork(),
             window: Window::default(),
@@ -444,6 +506,7 @@ impl Default for Config {
             ignore_selection_fg_color: false,
             confirm_before_quit: true,
             hide_cursor_when_typing: false,
+            draw_bold_text_with_light_colors: false,
         }
     }
 }
@@ -890,24 +953,6 @@ mod tests {
         assert_eq!(result.colors.tabs, hex_to_color_arr("#030303"));
         assert_eq!(result.colors.white, hex_to_color_arr("#000000"));
         assert_eq!(result.colors.yellow, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.dim_black, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.dim_blue, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.dim_cyan, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.dim_foreground, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.dim_green, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.dim_magenta, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.dim_red, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.dim_white, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.dim_yellow, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.light_black, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.light_blue, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.light_cyan, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.light_foreground, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.light_green, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.light_magenta, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.light_red, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.light_white, hex_to_color_arr("#030303"));
-        assert_eq!(result.colors.light_yellow, hex_to_color_arr("#030303"));
         assert_eq!(
             result.colors.selection_background,
             hex_to_color_arr("#111111")
@@ -956,6 +1001,19 @@ mod tests {
         assert_eq!(result.shell.args, ["--hello"]);
     }
 
+    #[test]
+    fn test_shell_no_args() {
+        let result = create_temporary_config(
+            "change-shell-and-editor-no-args",
+            r#"
+            shell = { program = "/bin/fish" }
+        "#,
+        );
+
+        assert_eq!(result.shell.program, "/bin/fish");
+        assert_eq!(result.shell.args, Vec::<&str>::new());
+    }
+
     #[test]
     fn test_change_developer_and_performance() {
         let result = create_temporary_config(
